---
feature_story: FS_88_66_66_73
feature_title: intercept_invocation_func
feature_status: TEST
---

The purpose of the `intercept` func is to show what `InvocationInput`
client side receives for that (remaining) command line.

If there is a valid command line:

```sh
some_command           goto service prod downstream wert-pd-1
```

There should be a way to prepend all args by `intercept` and run this command line:

```sh
some_command intercept goto service prod downstream wert-pd-1
```
